==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridToolbarActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarActionsDescription } from "./WebGridToolbarActionsDescription";
/**
 * @hidden
 */
var WebGridToolbarActionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarActionsDescriptionMetadata, _super);
    function WebGridToolbarActionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarActionsDescriptionMetadata.b = function (a) {
        if (WebGridToolbarActionsDescriptionMetadata.a == null) {
            WebGridToolbarActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarActionsDescriptionMetadata.c(WebGridToolbarActionsDescriptionMetadata.a);
        }
        if (a.j(WebGridToolbarActionsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridToolbarActionsDescriptionMetadata.a);
    };
    WebGridToolbarActionsDescriptionMetadata.c = function (a) {
        WebGridToolbarContentDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarActions");
        a.item("__tagNameWC", "String:igc-grid-toolbar-actions");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("Actions", "Collection:WebGridToolbarBaseAction:WebGridToolbarBaseActionCollection:WebGridToolbarBaseAction");
        a.item("Name", "String");
    };
    WebGridToolbarActionsDescriptionMetadata.d = function (a) {
        WebGridToolbarActionsDescriptionMetadata.b(a);
        a.aa("WebGridToolbarActions", function () { return new WebGridToolbarActionsDescription(); });
        a.z("WebGridToolbarActions", WebGridToolbarActionsDescriptionMetadata.a);
    };
    WebGridToolbarActionsDescriptionMetadata.$t = markType(WebGridToolbarActionsDescriptionMetadata, 'WebGridToolbarActionsDescriptionMetadata');
    WebGridToolbarActionsDescriptionMetadata.a = null;
    return WebGridToolbarActionsDescriptionMetadata;
}(Base));
export { WebGridToolbarActionsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridToolbarActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarActionsDescription } from "./WebGridToolbarActionsDescription";
/**
 * @hidden
 */
var WebGridToolbarActionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarActionsDescriptionMetadata, _super);
    function WebGridToolbarActionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarActionsDescriptionMetadata.b = function (a) {
        if (WebGridToolbarActionsDescriptionMetadata.a == null) {
            WebGridToolbarActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarActionsDescriptionMetadata.c(WebGridToolbarActionsDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarActionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridToolbarActionsDescriptionMetadata.a);
    };
    WebGridToolbarActionsDescriptionMetadata.c = function (a) {
        WebGridToolbarContentDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:GridToolbarActions");
        a.item("__tagNameWC", "String:igc-grid-toolbar-actions");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("Actions", "Collection:WebGridToolbarBaseAction:WebGridToolbarBaseActionCollection:WebGridToolbarBaseAction");
        a.item("Name", "String");
    };
    WebGridToolbarActionsDescriptionMetadata.d = function (a) {
        WebGridToolbarActionsDescriptionMetadata.b(a);
        a.ac("WebGridToolbarActions", function () { return new WebGridToolbarActionsDescription(); });
        a.ab("WebGridToolbarActions", WebGridToolbarActionsDescriptionMetadata.a);
    };
    WebGridToolbarActionsDescriptionMetadata.$t = markType(WebGridToolbarActionsDescriptionMetadata, 'WebGridToolbarActionsDescriptionMetadata');
    WebGridToolbarActionsDescriptionMetadata.a = null;
    return WebGridToolbarActionsDescriptionMetadata;
}(Base));
export { WebGridToolbarActionsDescriptionMetadata };
